package ai

import (
	"context"
	"errors"
	"os"

	"github.com/rs/zerolog/log"
	"github.com/sashabaranov/go-openai"
	"pluja.dev/kycnot.me/database"
)

func GetTosReviews(text string) ([]database.TosReview, error) {
	if len(text) < 10 {
		return nil, errors.New("empty text")
	}

	promptPrice := 0.005
	completionPrice := 0.015
	model := openai.GPT4o

	// Call the OpenAI API
	var highlights []database.TosReview
	client := openai.NewClient(os.Getenv("OPENAI_API_KEY"))
	resp, err := client.CreateChatCompletion(
		context.Background(),
		openai.ChatCompletionRequest{
			Model:          model,
			ResponseFormat: &openai.ChatCompletionResponseFormat{Type: openai.ChatCompletionResponseFormatTypeJSONObject},
			Messages: []openai.ChatCompletionMessage{
				{
					Role:    openai.ChatMessageRoleSystem,
					Content: sysPrompt,
				},
				{
					Role:    openai.ChatMessageRoleUser,
					Content: text,
				},
			},
		},
	)
	if err != nil {
		log.Debug().Err(err).Msg("Could not get response from OpenAI")
		return highlights, err
	}

	log.Printf("Total Tokens: %v", resp.Usage.TotalTokens)
	log.Printf("Price for this request: $%v", float64(resp.Usage.PromptTokens/1000)*promptPrice+float64(resp.Usage.CompletionTokens/1000)*completionPrice)

	if len(resp.Choices) == 0 {
		return highlights, nil
	}

	highlights, err = jsonToHighlights(resp.Choices[0].Message.Content)
	if err != nil {
		return highlights, err
	}
	return highlights, nil
}
