package tos_scraper

import (
	"time"

	"github.com/rs/zerolog/log"

	"pluja.dev/kycnot.me/database"
	"pluja.dev/kycnot.me/utils/ai"
)

func TrigerScraping() {
	log.Info().Msg("Starting ToS analysis...")
	services, err := database.Pb.GetServices("pending=false && listed=true", "")
	if err != nil {
		log.Error().Err(err).Msg("Could not get services from DB")
		return
	}

	log.Debug().Msgf("Found %v services", len(services))

	// For each service, run the scraper
	for _, service := range services {
		log.Debug().Str("Name", service.Name).Msgf("Scraping ToS")
		if len(service.TosUrls) == 0 {
			log.Error().Msgf("Service %v has no ToS URL", service.Name)
			continue
		}

		body, err := GetWithJina(service.TosUrls[0])
		if err != nil {
			log.Error().Err(err).Msgf("Could not get body from %v", service.TosUrls[0])
			continue
		}

		// Check if service.LastTosReview is not older than one month, skip
		if service.LastTosReview != "" {
			log.Debug().Msgf("Last review for %s: %s", service.Name, service.LastTosReview)
			t, _ := time.Parse("2006-01-02 15:04:05.000Z", service.LastTosReview)
			if time.Since(t) < 30*24*time.Hour {
				log.Debug().Msgf("Service %v ToS review is not older than one month, skipping", service.Name)
				continue
			}
		}

		highlights, err := ai.GetTosReviews(body)
		if err != nil {
			log.Error().Err(err).Msgf("Could not parse ToS from %v", service.TosUrls[0])
			continue
		}

		log.Debug().Msgf("Found %v highlights", len(highlights))
		service.TosReviews = highlights
		service.LastTosReview = time.Now().Format("2006-01-02 15:04:05.000Z")
		err = database.Pb.UpdateService(service.ID, service)
		if err != nil {
			log.Error().Err(err).Msgf("Could not save ToS highlights from %v", service.TosUrls[0])
			continue
		}
	}

	log.Info().Msg("Finished scraping ToS")
}
